@@ -170,7 +170,7 @@ impl RemotePullRequest for GitLabMergeRequest {
 	}
 
 	fn merge_commit(&self) -> Option<String> {
-		self.merge_commit_sha.clone()
+		self.merge_commit_sha.clone().or(Some(self.sha.clone()))
 	}
 }
 
@@ -234,7 +234,7 @@ impl TryFrom<Remote> for GitLabClient {
 	type Error = Error;
 	fn try_from(remote: Remote) -> Result<Self> {
 		Ok(Self {
-			client: create_remote_client(&remote, "application/json")?,
+			client: remote.create_client("application/json")?,
 			remote,
 		})
 	}
@@ -310,4 +310,13 @@ mod test {
 
 		assert_eq!(Some(1626610479), remote_commit.timestamp());
 	}
+
+	#[test]
+	fn merge_request_no_merge_commit() {
+		let mr = GitLabMergeRequest {
+			sha: String::from("1d244937ee6ceb8e0314a4a201ba93a7a61f2071"),
+			..Default::default()
+		};
+		assert!(mr.merge_commit().is_some());
+	}
 }
