@@ -40,13 +40,17 @@ use git_cliff_core::{
 	DEFAULT_CONFIG,
 	IGNORE_FILE,
 };
+use glob::Pattern;
 use std::env;
 use std::fs::{
 	self,
 	File,
 };
 use std::io;
-use std::path::Path;
+use std::path::{
+	Path,
+	PathBuf,
+};
 use std::time::{
 	SystemTime,
 	UNIX_EPOCH,
@@ -100,7 +104,7 @@ fn process_repository<'a>(
 			return true;
 		}
 
-		let count = count_tags.map_or(true, |r| {
+		let count = count_tags.is_none_or(|r| {
 			let count_tag = r.is_match(name);
 			if count_tag {
 				trace!("Counting release: {}", name);
@@ -153,6 +157,9 @@ fn process_repository<'a>(
 			}
 		}
 	}
+	if args.use_native_tls {
+		config.remote.enable_native_tls();
+	}
 
 	// Print debug information about configuration and arguments.
 	log::trace!("Arguments: {:#?}", args);
@@ -210,9 +217,29 @@ fn process_repository<'a>(
 			}
 		}
 	}
+
+	// Include only the current directory if not running from the root repository
+	let mut include_path = args.include_path.clone();
+	if let Some(mut path_diff) =
+		pathdiff::diff_paths(env::current_dir()?, repository.path())
+	{
+		if args.workdir.is_none() &&
+			include_path.is_none() &&
+			path_diff != Path::new("")
+		{
+			info!(
+				"Including changes from the current directory: {:?}",
+				path_diff.display()
+			);
+			path_diff.extend(["**", "*"]);
+			include_path =
+				Some(vec![Pattern::new(path_diff.to_string_lossy().as_ref())?]);
+		}
+	}
+
 	let mut commits = repository.commits(
 		commit_range.as_deref(),
-		args.include_path.clone(),
+		include_path,
 		args.exclude_path.clone(),
 	)?;
 	if let Some(commit_limit_value) = config.git.limit_commits {
@@ -250,7 +277,7 @@ fn process_repository<'a>(
 		let commit = Commit::from(git_commit);
 		let commit_id = commit.id.to_string();
 		release.commits.push(commit);
-		release.repository = Some(repository.path.to_string_lossy().into_owned());
+		release.repository = Some(repository.path().to_string_lossy().into_owned());
 		if let Some(tag) = tags.get(&commit_id) {
 			release.version = Some(tag.name.to_string());
 			release.message.clone_from(&tag.message);
@@ -337,7 +364,7 @@ fn process_repository<'a>(
 		if let Some(latest_release) = releases
 			.iter_mut()
 			.filter(|release| !release.commits.is_empty())
-			.last()
+			.next_back()
 		{
 			latest_release.message = Some(message.to_owned());
 		}
@@ -347,7 +374,51 @@ fn process_repository<'a>(
 }
 
 /// Runs `git-cliff`.
-pub fn run(mut args: Opt) -> Result<()> {
+///
+/// # Example
+///
+/// ```no_run
+/// use clap::Parser;
+/// use git_cliff::args::Opt;
+/// use git_cliff_core::error::Result;
+///
+/// fn main() -> Result<()> {
+/// 	let args = Opt::parse();
+/// 	git_cliff::run(args)?;
+/// 	Ok(())
+/// }
+/// ```
+pub fn run(args: Opt) -> Result<()> {
+	run_with_changelog_modifier(args, |_| Ok(()))
+}
+
+/// Runs `git-cliff` with a changelog modifier.
+///
+/// This is useful if you want to modify the [`Changelog`] before
+/// it's written or the context is printed (depending how git-cliff is started).
+///
+/// # Example
+///
+/// ```no_run
+/// use clap::Parser;
+/// use git_cliff::args::Opt;
+/// use git_cliff_core::error::Result;
+///
+/// fn main() -> Result<()> {
+/// 	let args = Opt::parse();
+///
+/// 	git_cliff::run_with_changelog_modifier(args, |changelog| {
+/// 		println!("Releases: {:?}", changelog.releases);
+/// 		Ok(())
+/// 	})?;
+///
+/// 	Ok(())
+/// }
+/// ```
+pub fn run_with_changelog_modifier(
+	mut args: Opt,
+	changelog_modifier: impl FnOnce(&mut Changelog) -> Result<()>,
+) -> Result<()> {
 	// Check if there is a new version available.
 	#[cfg(feature = "update-informer")]
 	check_new_version();
@@ -358,12 +429,19 @@ pub fn run(mut args: Opt) -> Result<()> {
 			Some(ref name) => BuiltinConfig::get_config(name.to_string())?,
 			None => EmbeddedConfig::get_config()?,
 		};
+
+		let config_path = if args.config == PathBuf::from(DEFAULT_CONFIG) {
+			PathBuf::from(DEFAULT_CONFIG)
+		} else {
+			args.config.clone()
+		};
+
 		info!(
 			"Saving the configuration file{} to {:?}",
 			init_config.map(|v| format!(" ({v})")).unwrap_or_default(),
-			DEFAULT_CONFIG
+			config_path
 		);
-		fs::write(DEFAULT_CONFIG, contents)?;
+		fs::write(config_path, contents)?;
 		return Ok(());
 	}
 
@@ -387,7 +465,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 		}
 	}
 
-	// Parse the configuration file.
+	// Set path for the configuration file.
 	let mut path = args.config.clone();
 	if !path.exists() {
 		if let Some(config_path) = dirs::config_dir()
@@ -397,6 +475,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 		}
 	}
 
+	// Parse the configuration file.
 	// Load the default configuration if necessary.
 	let mut config = if let Ok((config, name)) = builtin_config {
 		info!("Using built-in configuration file: {name}");
@@ -405,6 +484,20 @@ pub fn run(mut args: Opt) -> Result<()> {
 		Config::parse(&path)?
 	} else if let Some(contents) = Config::read_from_manifest()? {
 		Config::parse_from_str(&contents)?
+	} else if let Some(discovered_path) =
+		env::current_dir()?.ancestors().find_map(|dir| {
+			let path = dir.join(DEFAULT_CONFIG);
+			if path.is_file() {
+				Some(path)
+			} else {
+				None
+			}
+		}) {
+		info!(
+			"Using configuration from parent directory: {}",
+			discovered_path.display()
+		);
+		Config::parse(&discovered_path)?
 	} else {
 		if !args.context {
 			warn!(
@@ -590,6 +683,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 		}
 		Changelog::new(releases, &config)?
 	};
+	changelog_modifier(&mut changelog)?;
 
 	// Print the result.
 	let mut out: Box<dyn io::Write> = if let Some(path) = &output {
